@@ -5,6 +5,8 @@ import os
 from contextlib import contextmanager
 from threading  import Lock
 import concurrent.futures
+
+from .log import create_logger
 # FILE IO
 
 def make_dir(path):
@@ -58,13 +60,22 @@ def read_json(filepath):
     returns an empty dict if the file is not found'''
     try:
         with open(filepath,'r') as f:
-            users = json.load(f)
-            return users
+            d = json.load(f)
+            return d
     # on not found return an empty dict
     except FileNotFoundError:
         print(f'"{filepath}" not found, returning an empty dictionary')
         return {}
 
+def update_json(dictionary,filepath):
+    '''A convenience combination of read_json and write_json'''
+    d = read_json(filepath)
+    d.update(dictionary)
+    write_json(d,filepath)
+    return d
+
+
+
 # PICKLE
 def save_picke(data,filepath):
     with open(filepath,'wb') as file:
